@@ -37,8 +37,8 @@ ShowArchiveStructureDialog::ShowArchiveStructureDialog(const QString &filename,
     : QDialog(parent)
     , mFileName(filename)
     , mTreeWidget(new QTreeWidget(this))
-    , mExtractFile(new QPushButton(i18n("Extract Selected File"), this))
-    , mOpenFile(new QPushButton(i18n("Open Selected File"), this))
+    , mExtractFile(new QPushButton(i18nc("@action:button", "Extract Selected File"), this))
+    , mOpenFile(new QPushButton(i18nc("@action:button", "Open Selected File"), this))
 {
     setWindowTitle(i18nc("@title:window", "Show Archive Content on file \"%1\"", filename));
     setModal(true);
@@ -48,7 +48,7 @@ ShowArchiveStructureDialog::ShowArchiveStructureDialog(const QString &filename,
     mTreeWidget->setAlternatingRowColors(true);
 
     auto searchLine = new KTreeWidgetSearchLine(this, mTreeWidget);
-    searchLine->setPlaceholderText(i18n("Search..."));
+    searchLine->setPlaceholderText(i18nc("@info:placeholder", "Search..."));
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     auto user1Button = new QPushButton(this);
     user1Button->setText(i18n("Save As Text..."));
